@@ -3,7 +3,6 @@ from io import StringIO
 import sys
 import re
 
-from nose.tools import eq_
 from sqlalchemy.engine import create_engine
 from sqlalchemy.schema import (MetaData, Table, Column, CheckConstraint, UniqueConstraint, Index, ForeignKey,
                                ForeignKeyConstraint)
@@ -42,7 +41,7 @@ class TestModelGenerator(object):
             Column('number', NUMERIC(10, asdecimal=False)),
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Boolean, Column, Enum, MetaData, Numeric, Table
 
@@ -56,7 +55,7 @@ t_simple_items = Table(
     Column('bool', Boolean),
     Column('number', Numeric(10, asdecimal=False))
 )
-""")
+"""
 
     def test_boolean_detection(self):
         Table(
@@ -69,7 +68,7 @@ t_simple_items = Table(
             CheckConstraint('simple_items.bool3 IN (0, 1)')
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Boolean, Column, MetaData, Table
 
@@ -83,7 +82,7 @@ t_simple_items = Table(
     Column('bool2', Boolean),
     Column('bool3', Boolean)
 )
-""")
+"""
 
     def test_enum_detection(self):
         Table(
@@ -92,7 +91,7 @@ t_simple_items = Table(
             CheckConstraint(r"simple_items.enum IN ('A', '\'B', 'C')")
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, Enum, MetaData, Table
 
@@ -104,7 +103,7 @@ t_simple_items = Table(
     'simple_items', metadata,
     Column('enum', Enum('A', "\\\\'B", 'C'))
 )
-""")
+"""
 
     def test_column_adaptation(self):
         Table(
@@ -113,7 +112,7 @@ t_simple_items = Table(
             Column('length', DOUBLE_PRECISION)
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import BigInteger, Column, Float, MetaData, Table
 
@@ -126,7 +125,7 @@ t_simple_items = Table(
     Column('id', BigInteger),
     Column('length', Float)
 )
-""")
+"""
 
     def test_mysql_column_types(self):
         Table(
@@ -135,7 +134,7 @@ t_simple_items = Table(
             Column('name', mysql.VARCHAR(255))
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, Integer, MetaData, String, Table
 
@@ -148,7 +147,7 @@ t_simple_items = Table(
     Column('id', Integer),
     Column('name', String(255))
 )
-""")
+"""
 
     def test_constraints_table(self):
         Table(
@@ -159,7 +158,7 @@ t_simple_items = Table(
             UniqueConstraint('id', 'number')
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import CheckConstraint, Column, Integer, MetaData, Table, UniqueConstraint
 
@@ -174,7 +173,7 @@ t_simple_items = Table(
     CheckConstraint('number > 0'),
     UniqueConstraint('id', 'number')
 )
-""")
+"""
 
     def test_constraints_class(self):
         Table(
@@ -185,7 +184,7 @@ t_simple_items = Table(
             UniqueConstraint('id', 'number')
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import CheckConstraint, Column, Integer, UniqueConstraint
 from sqlalchemy.ext.declarative import declarative_base
@@ -204,7 +203,7 @@ class SimpleItem(Base):
 
     id = Column(Integer, primary_key=True)
     number = Column(Integer)
-""")
+"""
 
     def test_noindexes_table(self):
         simple_items = Table(
@@ -214,7 +213,7 @@ class SimpleItem(Base):
         )
         simple_items.indexes.add(Index('idx_number', simple_items.c.number))
 
-        eq_(self.generate_code(noindexes=True), """\
+        assert self.generate_code(noindexes=True) == """\
 # coding: utf-8
 from sqlalchemy import CheckConstraint, Column, Integer, MetaData, Table
 
@@ -227,7 +226,7 @@ t_simple_items = Table(
     Column('number', Integer),
     CheckConstraint('number > 2')
 )
-""")
+"""
 
     def test_noconstraints_table(self):
         simple_items = Table(
@@ -237,7 +236,7 @@ t_simple_items = Table(
         )
         simple_items.indexes.add(Index('idx_number', simple_items.c.number))
 
-        eq_(self.generate_code(noconstraints=True), """\
+        assert self.generate_code(noconstraints=True) == """\
 # coding: utf-8
 from sqlalchemy import Column, Integer, MetaData, Table
 
@@ -249,7 +248,7 @@ t_simple_items = Table(
     'simple_items', metadata,
     Column('number', Integer, index=True)
 )
-""")
+"""
 
     def test_indexes_table(self):
         simple_items = Table(
@@ -260,8 +259,9 @@ t_simple_items = Table(
         )
         simple_items.indexes.add(Index('idx_number', simple_items.c.number))
         simple_items.indexes.add(Index('idx_text_number', simple_items.c.text, simple_items.c.number))
+        simple_items.indexes.add(Index('idx_text', simple_items.c.text, unique=True))
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, Index, Integer, MetaData, String, Table
 
@@ -273,10 +273,10 @@ t_simple_items = Table(
     'simple_items', metadata,
     Column('id', Integer),
     Column('number', Integer, index=True),
-    Column('text', String),
+    Column('text', String, unique=True),
     Index('idx_text_number', 'text', 'number')
 )
-""")
+"""
 
     def test_indexes_class(self):
         simple_items = Table(
@@ -287,8 +287,9 @@ t_simple_items = Table(
         )
         simple_items.indexes.add(Index('idx_number', simple_items.c.number))
         simple_items.indexes.add(Index('idx_text_number', simple_items.c.text, simple_items.c.number))
+        simple_items.indexes.add(Index('idx_text', simple_items.c.text, unique=True))
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, Index, Integer, String
 from sqlalchemy.ext.declarative import declarative_base
@@ -306,8 +307,8 @@ class SimpleItem(Base):
 
     id = Column(Integer, primary_key=True)
     number = Column(Integer, index=True)
-    text = Column(String)
-""")
+    text = Column(String, unique=True)
+"""
 
     def test_onetomany(self):
         Table(
@@ -321,7 +322,7 @@ class SimpleItem(Base):
             Column('id', INTEGER, primary_key=True)
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer
 from sqlalchemy.orm import relationship
@@ -345,7 +346,7 @@ class SimpleItem(Base):
     container_id = Column(ForeignKey('simple_containers.id'))
 
     container = relationship('SimpleContainer')
-""")
+"""
 
     def test_onetomany_selfref(self):
         Table(
@@ -355,7 +356,7 @@ class SimpleItem(Base):
             ForeignKeyConstraint(['parent_item_id'], ['simple_items.id'])
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer
 from sqlalchemy.orm import relationship
@@ -373,7 +374,7 @@ class SimpleItem(Base):
     parent_item_id = Column(ForeignKey('simple_items.id'))
 
     parent_item = relationship('SimpleItem', remote_side=[id])
-""")
+"""
 
     def test_onetomany_selfref_multi(self):
         Table(
@@ -385,7 +386,7 @@ class SimpleItem(Base):
             ForeignKeyConstraint(['top_item_id'], ['simple_items.id'])
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer
 from sqlalchemy.orm import relationship
@@ -405,7 +406,7 @@ class SimpleItem(Base):
 
     parent_item = relationship('SimpleItem', remote_side=[id], primaryjoin='SimpleItem.parent_item_id == SimpleItem.id')
     top_item = relationship('SimpleItem', remote_side=[id], primaryjoin='SimpleItem.top_item_id == SimpleItem.id')
-""")
+"""
 
     def test_onetomany_composite(self):
         Table(
@@ -421,7 +422,7 @@ class SimpleItem(Base):
             Column('id2', INTEGER, primary_key=True)
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKeyConstraint, Integer
 from sqlalchemy.orm import relationship
@@ -450,7 +451,7 @@ class SimpleItem(Base):
     container_id2 = Column(Integer)
 
     simple_container = relationship('SimpleContainer')
-""")
+"""
 
     def test_onetomany_multiref(self):
         Table(
@@ -466,7 +467,7 @@ class SimpleItem(Base):
             Column('id', INTEGER, primary_key=True)
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer
 from sqlalchemy.orm import relationship
@@ -490,9 +491,10 @@ class SimpleItem(Base):
     parent_container_id = Column(ForeignKey('simple_containers.id'))
     top_container_id = Column(ForeignKey('simple_containers.id'))
 
-    parent_container = relationship('SimpleContainer', primaryjoin='SimpleItem.parent_container_id == SimpleContainer.id')
+    parent_container = relationship('SimpleContainer', \
+primaryjoin='SimpleItem.parent_container_id == SimpleContainer.id')
     top_container = relationship('SimpleContainer', primaryjoin='SimpleItem.top_container_id == SimpleContainer.id')
-""")
+"""
 
     def test_onetoone(self):
         Table(
@@ -507,7 +509,7 @@ class SimpleItem(Base):
             Column('id', INTEGER, primary_key=True)
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer
 from sqlalchemy.orm import relationship
@@ -531,7 +533,7 @@ class SimpleItem(Base):
     other_item_id = Column(ForeignKey('other_items.id'), unique=True)
 
     other_item = relationship('OtherItem', uselist=False)
-""")
+"""
 
     def test_onetomany_noinflect(self):
         Table(
@@ -545,7 +547,7 @@ class SimpleItem(Base):
             Column('id', INTEGER, primary_key=True)
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer
 from sqlalchemy.orm import relationship
@@ -569,7 +571,7 @@ class Oglkrogk(Base):
     fehwiuhfiwID = Column(ForeignKey('fehwiuhfiw.id'))
 
     fehwiuhfiw = relationship('Fehwiuhfiw')
-""")
+"""
 
     def test_manytomany(self):
         Table(
@@ -588,7 +590,7 @@ class Oglkrogk(Base):
             ForeignKeyConstraint(['container_id'], ['simple_containers.id'])
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer, Table
 from sqlalchemy.orm import relationship
@@ -618,7 +620,7 @@ class SimpleItem(Base):
     __tablename__ = 'simple_items'
 
     id = Column(Integer, primary_key=True)
-""")
+"""
 
     def test_manytomany_selfref(self):
         Table(
@@ -633,7 +635,7 @@ class SimpleItem(Base):
             ForeignKeyConstraint(['child_id'], ['simple_items.id'])
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer, Table
 from sqlalchemy.orm import relationship
@@ -662,7 +664,7 @@ class SimpleItem(Base):
         primaryjoin='SimpleItem.id == child_items.c.child_id',
         secondaryjoin='SimpleItem.id == child_items.c.parent_id'
     )
-""")
+"""
 
     def test_manytomany_composite(self):
         Table(
@@ -685,7 +687,7 @@ class SimpleItem(Base):
             ForeignKeyConstraint(['container_id1', 'container_id2'], ['simple_containers.id1', 'simple_containers.id2'])
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKeyConstraint, Integer, Table
 from sqlalchemy.orm import relationship
@@ -721,7 +723,7 @@ class SimpleItem(Base):
 
     id1 = Column(Integer, primary_key=True, nullable=False)
     id2 = Column(Integer, primary_key=True, nullable=False)
-""")
+"""
 
     def test_joined_inheritance(self):
         Table(
@@ -742,7 +744,7 @@ class SimpleItem(Base):
             ForeignKeyConstraint(['super_item_id'], ['simple_super_items.id'])
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer
 from sqlalchemy.ext.declarative import declarative_base
@@ -771,7 +773,7 @@ class SimpleSubItem(SimpleItem):
 
     simple_items_id = Column(ForeignKey('simple_items.super_item_id'), primary_key=True)
     data3 = Column(Integer)
-""")
+"""
 
     def test_no_inflect(self):
         Table(
@@ -779,7 +781,7 @@ class SimpleSubItem(SimpleItem):
             Column('id', INTEGER, primary_key=True)
         )
 
-        eq_(self.generate_code(noinflect=True), """\
+        assert self.generate_code(noinflect=True) == """\
 # coding: utf-8
 from sqlalchemy import Column, Integer
 from sqlalchemy.ext.declarative import declarative_base
@@ -793,7 +795,7 @@ class SimpleItems(Base):
     __tablename__ = 'simple_items'
 
     id = Column(Integer, primary_key=True)
-""")
+"""
 
     def test_table_kwargs(self):
         Table(
@@ -802,7 +804,7 @@ class SimpleItems(Base):
             schema='testschema'
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, Integer
 from sqlalchemy.ext.declarative import declarative_base
@@ -817,7 +819,7 @@ class SimpleItem(Base):
     __table_args__ = {'schema': 'testschema'}
 
     id = Column(Integer, primary_key=True)
-""")
+"""
 
     def test_table_args_kwargs(self):
         simple_items = Table(
@@ -828,7 +830,7 @@ class SimpleItem(Base):
         )
         simple_items.indexes.add(Index('testidx', simple_items.c.id, simple_items.c.name))
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, Index, Integer, String
 from sqlalchemy.ext.declarative import declarative_base
@@ -847,7 +849,7 @@ class SimpleItem(Base):
 
     id = Column(Integer, primary_key=True)
     name = Column(String)
-""")
+"""
 
     def test_schema_table(self):
         Table(
@@ -856,7 +858,7 @@ class SimpleItem(Base):
             schema='testschema'
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, MetaData, String, Table
 
@@ -869,7 +871,30 @@ t_simple_items = Table(
     Column('name', String),
     schema='testschema'
 )
-""")
+"""
+
+    def test_schema_boolean(self):
+        Table(
+            'simple_items', self.metadata,
+            Column('bool1', INTEGER),
+            CheckConstraint('testschema.simple_items.bool1 IN (0, 1)'),
+            schema='testschema'
+        )
+
+        assert self.generate_code() == """\
+# coding: utf-8
+from sqlalchemy import Boolean, Column, MetaData, Table
+
+
+metadata = MetaData()
+
+
+t_simple_items = Table(
+    'simple_items', metadata,
+    Column('bool1', Boolean),
+    schema='testschema'
+)
+"""
 
     def test_foreign_key_options(self):
         Table(
@@ -877,7 +902,7 @@ t_simple_items = Table(
             Column('name', VARCHAR, ForeignKey('simple_items.name', deferrable=True, initially='DEFERRED'))
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, MetaData, String, Table
 
@@ -889,7 +914,7 @@ t_simple_items = Table(
     'simple_items', metadata,
     Column('name', String, ForeignKey('simple_items.name', deferrable=True, initially='DEFERRED'))
 )
-""")
+"""
 
     def test_foreign_key_schema(self):
         Table(
@@ -904,7 +929,7 @@ t_simple_items = Table(
             schema='otherschema'
         )
 
-        eq_(self.generate_code(), """\
+        assert self.generate_code() == """\
 # coding: utf-8
 from sqlalchemy import Column, ForeignKey, Integer
 from sqlalchemy.orm import relationship
@@ -929,4 +954,4 @@ class OtherItem(Base):
     __table_args__ = {'schema': 'otherschema'}
 
     id = Column(Integer, primary_key=True)
-""")
+"""
